@@ -1,3 +1,4 @@
+#![allow(clippy::integer_arithmetic)]
 //! Defines a composable Instruction type and a memory-efficient CompiledInstruction.
 
 use crate::sanitize::Sanitize;
@@ -214,10 +215,8 @@ pub enum InstructionError {
     /// Unsupported sysvar
     #[error("Unsupported sysvar")]
     UnsupportedSysvar,
-
-    /// Illegal account owner
-    #[error("Provided owner is not allowed")]
-    IllegalOwner,
+    // Note: For any new error added here an equivilent ProgramError and it's
+    // conversions must also be added
 }
 
 #[derive(Debug, PartialEq, Clone, Serialize, Deserialize)]
